<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" indent="yes"/>
	
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<fo:layout-master-set>
			
				<fo:simple-page-master master-name="TOC" 
					page-height="11in" page-width="8.5in" margin=".5in">
					<fo:region-body margin=".5in"/>
					<fo:region-before region-name="TocHead" extent=".5in"/>
					<fo:region-after region-name="TocFoot" extent=".5in"/>
				</fo:simple-page-master>
				
				<fo:simple-page-master master-name="StoriesOdd" 
					page-height="11in" page-width="8.5in" margin=".5in">
					<fo:region-body margin=".5in"/>
					<fo:region-before region-name="oddHead" extent=".5in"/>
					<fo:region-after region-name="oddFoot" extent=".5in"/>
				</fo:simple-page-master>
				
				<fo:simple-page-master master-name="StoriesEven" 
					page-height="11in" page-width="8.5in" margin=".5in">
					<fo:region-body margin=".5in"/>
					<fo:region-before region-name="evenHead" extent=".5in"/>
					<fo:region-after region-name="evenFoot" extent=".5in"/>
				</fo:simple-page-master>
				
				<fo:page-sequence-master master-name="Stories">
					<fo:repeatable-page-master-alternatives>
						<fo:conditional-page-master-reference 
							master-reference="StoriesOdd" odd-or-even="odd"/>
						<fo:conditional-page-master-reference 
							master-reference="StoriesEven" odd-or-even="even"/>
					</fo:repeatable-page-master-alternatives>
				</fo:page-sequence-master>
				
			</fo:layout-master-set>
			
			<fo:page-sequence master-reference="TOC" format="i">
			
				<fo:static-content flow-name="TocHead">
					<fo:block border-bottom-width="thin" border-bottom-style="solid" 
						border-bottom-color="green" font-weight="bold" text-align="outside">
						<xsl:text>Table of Contents</xsl:text>
					</fo:block>
				</fo:static-content>
				
				<fo:static-content flow-name="TocFoot">
					<fo:block border-bottom-width="thin" border-bottom-style="solid" 
						border-bottom-color="green" font-weight="bold" text-align="outside">
						<fo:page-number/>
					</fo:block>
				</fo:static-content>
				
				<fo:flow flow-name="xsl-region-body">
					<fo:block text-align="center" font-weight="bold" 
						font-size="larger">
						<xsl:text>Table of Contents</xsl:text>
					</fo:block>
					<xsl:apply-templates mode="TOC"/>
				</fo:flow>
				
			</fo:page-sequence>
			
			<fo:page-sequence master-reference="Stories" initial-page-number="1">
			
				<fo:static-content flow-name="oddHead">
					<fo:block border-bottom-width="thin" border-bottom-style="solid" 
						border-bottom-color="green" font-weight="bold" text-align="outside">
						<fo:retrieve-marker retrieve-class-name="StoryTitle"
							retrieve-position="first-including-carryover"/>
					</fo:block>
				</fo:static-content>
				
				<fo:static-content flow-name="evenHead">
					<fo:block border-bottom-width="thin" border-bottom-style="solid" 
						border-bottom-color="green" font-weight="bold" text-align="outside">
						<fo:retrieve-marker retrieve-class-name="StoryTitle"
							retrieve-position="first-including-carryover"/>
					</fo:block>
				</fo:static-content>
				
				<fo:static-content flow-name="oddFoot">
					<fo:block border-bottom-width="thin" border-bottom-style="solid"
						border-bottom-color="green" font-weight="bold" text-align="right">
						<fo:page-number/>
					</fo:block>
				</fo:static-content>
				
				<fo:static-content flow-name="evenFoot">
					<fo:block border-bottom-width="thin" border-bottom-style="solid" 
						border-bottom-color="green" font-weight="bold" text-align="left">
						<fo:page-number/>
					</fo:block>
				</fo:static-content>
				
				<fo:flow flow-name="xsl-region-body">
					<xsl:apply-templates mode="Stories"/>
				</fo:flow>
				
			</fo:page-sequence>
			
		</fo:root>
		
	</xsl:template>
	
	<xsl:template match="body/div/h2" mode="TOC">
		<fo:block font-size="smaller" space-after=".1in" 
			space-before=".15in" text-align-last="justify">
			<fo:basic-link internal-destination="{generate-id(.)}">
				<xsl:value-of select="."/>
				<fo:leader leader-pattern="dots"/>
				<fo:page-number-citation ref-id="{generate-id(.)}"/>
			</fo:basic-link>
		</fo:block>
	</xsl:template>
	
	<xsl:template match="body/div/h2" mode="Stories">
		<fo:block font-weight="bold" font-size="larger" 
			id="{generate-id(.)}" break-before="odd-page">
			<fo:marker marker-class-name="StoryTitle">
				<xsl:value-of select="."/>
			</fo:marker>
			<xsl:value-of select="."/>
		</fo:block>
	</xsl:template>
	
	<xsl:template match="body/div/p" mode="Stories">
		<fo:block margin-top="12pt" keep-together="always">
			<xsl:apply-templates mode="Stories"/>
		</fo:block>
	</xsl:template>
	
	<xsl:template match="head | h1 | a | p" mode="TOC"/>
	<xsl:template match="head | h1 | a" mode="Stories"/>
</xsl:stylesheet>