<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
			xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
			xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" indent="yes"/>
	
	<xsl:template match="/">
		<fo:root>
		
			<!--BEGIN PAGE MASTERS-->
			<fo:layout-master-set>
			
				<fo:simple-page-master master-name="TitlePage" 
					page-height="11in" page-width="8.5in" 
					margin-top=".5in" margin-bottom=".5in" margin-left="1in" margin-right="1in">
					<fo:region-body margin="1in"/>
				</fo:simple-page-master>
				
				<fo:simple-page-master master-name="TocRight" 
					page-height="11in" page-width="8.5in" 
					margin-top=".5in" margin-bottom=".5in" margin-left="1in" margin-right="1in">
					<fo:region-body margin-top=".5in" margin-bottom="1in"/>
					<fo:region-before extent=".6in" region-name="top-right-and-left"/>
					<fo:region-after extent=".6in" region-name="bottom-right"/>
				</fo:simple-page-master>
				
				<fo:simple-page-master master-name="TocLeft" 
					page-height="11in" page-width="8.5in" 
					margin-top=".5in" margin-bottom=".5in" margin-left="1in" margin-right="1in">
					<fo:region-body margin-top=".5in" margin-bottom="1in"/>
					<fo:region-before extent=".6in" region-name="top-right-and-left"/>
					<fo:region-after extent=".6in" region-name="bottom-left"/>
				</fo:simple-page-master>
				
				<fo:page-sequence-master master-name="TOC">
					<fo:repeatable-page-master-alternatives maximum-repeats="no-limit">
						<fo:conditional-page-master-reference odd-or-even="odd" 
							master-reference="TocRight"/>
						<fo:conditional-page-master-reference odd-or-even="even" 
							master-reference="TocLeft"/>
					</fo:repeatable-page-master-alternatives>
				</fo:page-sequence-master>
				
				<fo:simple-page-master master-name="PageRight" 
					page-height="11in" page-width="8.5in"
					margin-top=".5in" margin-bottom=".5in" margin-left="1in" margin-right="1in">
					<fo:region-body margin-top=".5in" margin-bottom="1in"/>
					<fo:region-before extent=".6in" region-name="top-right-and-left"/>
					<fo:region-after extent=".6in" region-name="bottom-right"/>
				</fo:simple-page-master>
				
				<fo:simple-page-master master-name="PageLeft" 
					page-height="11in" page-width="8.5in" 
					margin-top=".5in" margin-bottom=".5in" margin-left="1in" margin-right="1in">
					<fo:region-body margin-top=".5in" margin-bottom="1in"/>
					<fo:region-before extent=".6in" region-name="top-right-and-left"/>
					<fo:region-after extent=".6in" region-name="bottom-left"/>
				</fo:simple-page-master>
				
				<fo:page-sequence-master master-name="Song">
					<fo:repeatable-page-master-alternatives maximum-repeats="no-limit">
						<fo:conditional-page-master-reference odd-or-even="odd" 
							master-reference="PageRight"/>
						<fo:conditional-page-master-reference odd-or-even="even" 
							master-reference="PageLeft"/>
					</fo:repeatable-page-master-alternatives>
				</fo:page-sequence-master>
				
			</fo:layout-master-set>
			<!--END PAGE MASTERS-->
			<!--BEGIN PAGE SEQUENCES-->
			<fo:page-sequence master-reference="TitlePage" 
				force-page-count="end-on-even">
				<fo:flow flow-name="xsl-region-body">
					<fo:block text-align="center" font-size="18pt" id="TitlePage">
						<fo:block font-weight="bold" margin-bottom="1cm">
								Top <xsl:value-of select="count(//Song)"/>
								Classic Rock Songs of All Time
						</fo:block>
						<fo:block text-align="center">
							<fo:external-graphic src="url('{/Songs/@Image}')"/>
						</fo:block>
					</fo:block>
				</fo:flow>
			</fo:page-sequence>
			
			<fo:page-sequence master-reference="TOC">
			
				<fo:static-content flow-name="top-right-and-left">
					<fo:block font-family="Helvetica" font-size="10pt" text-align="outside" 
						padding-top=".05in" border-top-width="thin" border-top-color="#0000ff" 
						border-top-style="solid" font-weight="bold">
						Table of Contents
					</fo:block>
				</fo:static-content>
				
				<fo:static-content flow-name="bottom-right">
					<fo:block font-family="Helvetica" font-size="10pt" text-align="outside" 
						padding-top=".05in" border-top-width="thin" 
						border-top-color="#0000ff" border-top-style="solid">
						| <fo:page-number/>
					</fo:block>
				</fo:static-content>
				
				<fo:static-content flow-name="bottom-left">
					<fo:block font-family="Helvetica" font-size="10pt" text-align="outside"
						padding-top=".05in" border-top-width="thin" 
						border-top-color="#0000ff" border-top-style="solid">
						<fo:page-number/> |
					</fo:block>
				</fo:static-content>
				
				<fo:flow flow-name="xsl-region-body">
					<fo:block font-family="Helvetica" font-size="22pt" 
						font-weight="bold" text-align="center" space-after=".2in" id="TOC">
						Table of Contents
					</fo:block>
					<xsl:for-each select="Songs/Song">
						<fo:block font-family="Helvetica" font-size="12pt" font-weight="bold" 
							space-after=".1in">
							<fo:basic-link internal-destination="{generate-id(Title)}">
								<xsl:value-of select="Title"/>
							</fo:basic-link>
						</fo:block>
					</xsl:for-each>
					<fo:block id="LastPageToc" break-after="odd-page"/>
				</fo:flow>
				
			</fo:page-sequence>
			
			
			<fo:page-sequence master-reference="Song" initial-page-number="1">
				
				<fo:static-content flow-name="top-right-and-left">
					<fo:block font-family="Helvetica" font-size="10pt" text-align="outside" 
						padding-top=".05in" border-top-width=".05in" border-top-color="#0000ff" 
						border-top-style="solid" font-weight="bold">
						Song Title Placeholder
					</fo:block>
				</fo:static-content>
				
				<fo:static-content flow-name="bottom-right">
					<fo:block font-family="Helvetica" font-size="10pt"  text-align="outside"
						padding-top=".05in" border-top-width=".025in" 
						border-top-color="#0000ff" border-top-style="solid">
						| Page <fo:page-number/> of <fo:page-number-citation ref-id="LastPage"/>
					</fo:block>
				</fo:static-content>
				
				<fo:static-content flow-name="bottom-left">
					<fo:block font-family="Helvetica" font-size="10pt"  text-align="outside"
						padding-top=".05in" border-top-width=".025in" 
						border-top-color="#0000ff" border-top-style="solid">
						Page <fo:page-number/> of <fo:page-number-citation ref-id="LastPage"/> |
					</fo:block>
				</fo:static-content>
				
				<fo:flow flow-name="xsl-region-body">
				
					<xsl:for-each select="Songs/Song">
						<fo:block font-weight="bold" font-size="14pt" font-family="Times" 
							id="{generate-id(Title)}" break-before="page">
							<xsl:number format="1. "/>
							<xsl:value-of select="Title"/>
						</fo:block>
						<fo:block font-size="12pt" font-style="italic" font-family="Times" 
							margin-bottom=".1in" margin-left=".2in">
								- <xsl:value-of select="@Artist"/>
						</fo:block>
						<fo:block linefeed-treatment="preserve" white-space-collapse="false" wrap-option="wrap" white-space-treatment="preserve" font-size="10pt">
							<xsl:value-of select="Lyrics"/>
						</fo:block>
					</xsl:for-each>
					
					<fo:block id="LastPage"/>
					
				</fo:flow>
			</fo:page-sequence>
				
			<!--END PAGE SEQUENCES-->	
			
		</fo:root>
	</xsl:template>
	
</xsl:stylesheet>